@@ -1,4 +1,4 @@
-localpip_version = "0.0.11"
+localpip_version = "0.0.12"
 __author__ = "Alex BOURG"
 __copyright__ = "Copyright 2021"
 __license__ = "GPL"
@@ -9,6 +9,8 @@ __status__ = "Production"
 import os
 import sys
 import subprocess, sys
+from tkinter import filedialog as fd
+from tkinter.messagebox import showinfo
 
 
 def exitapp():
@@ -68,8 +70,8 @@ def install(package, action, path):
             )
 
         elif "numpy==1.19.2" in package and sys.version_info.minor == 9:
-            pass
-            # print(f" {package} is not compatible with Python 39")
+            # pass
+            print(f" {package} is not compatible with Python 39, higher version will be installed.")
 
         else:
             # try:
@@ -87,40 +89,63 @@ def install(package, action, path):
             print(x)
             if "Could not find a version that satisfies" in x:
                 print(f"{package} is not available in the local repo.")
+                print(f"Installing {package} from the internet...")
+                os.system(f"pip install {package}")
+                # pip = input(
+                #     "Will try to download it from the internet, do you want to continue? (yes/no): "
+                # ).lower()
                 # print(
-                #     f"Try installing it using the regular pip > pip install {package}"
+                #     "*******************************************************************************************************"
                 # )
-                pip = input(
-                    "Will try to download it from PYPI, do you want to continue? (yes/no): "
-                ).lower()
-                print(
-                    "*******************************************************************************************************"
-                )
-                if pip.startswith("y"):
-                    os.system(f"pip install {package}")
+                # if pip.startswith("y"):
+                #     os.system(f"pip install {package}")
             print()
-            print(f"*****{package} installation is completed!*****")
+            print(f"*****{package} installation has been completed!*****")
 
     # Uninstall command
-    if action == "uninstall":
+    elif action == "uninstall":
         print()
         print(
             " *******************************************************************************************************"
         )
-        print(f" uninstalling {package} ...")
+        print(f" Uninstalling {package} ...")
         print()
         print()
         os.system(f"pip {action} {package} -y")
         print()
-        print(f"*****{package} uninstallation is completed!*****")
+        print(f"*****{package} uninstallation has been completed!*****")
 
-    # Upgrade command
-    if action == "upgrade":
+    elif action == "download":
         print()
         print(
             " *******************************************************************************************************"
         )
-        print(f"Upgrading {package} ...")
+        print(f" Downloading {package} ...")
+        print()
+        print()
+        os.system(f"pip {action} {package}")
+        print()
+        print(f"*****{package} download has been completed!*****")
+
+    elif action == "wheel":
+        print()
+        print(
+            " *******************************************************************************************************"
+        )
+        print(f" Creating wheel for {package} ...")
+        print()
+        print()
+        os.system(f"pip {action} {package}")
+        print()
+        print(f"*****{package} wheel command has been completed!*****")
+
+    # Upgrade command
+    elif action == "upgrade":
+        print()
+        print(
+            " *******************************************************************************************************"
+        )
+        print(f" Upgrading {package} ...")
         print()
         print()
         if "pip" in package:
@@ -132,7 +157,7 @@ def install(package, action, path):
         else:
             os.system(f"pip install --no-index --find-links {path} {package} -U")
         print()
-        print(f"*****{package} upgrade is completed!*****")
+        print(f"*****{package} upgrade has been completed!*****")
 
 
 def pip_list():
@@ -146,7 +171,7 @@ def localpip_remove():
         "\n*******************************************************************************************************"
     )
     pip = input(
-        "localpip will be uninstalled, are you sure you want to continue? (yes/no): "
+        "localpip repository will be uninstalled, are you sure you want to continue? (yes/no): "
     ).lower()
     print()
     if pip.startswith("y"):
@@ -159,7 +184,7 @@ def localpip_remove():
             print(
                 "*******************************************************************************************************"
             )
-            print("localpip packages has been uninstalled successfully!")
+            print("localpip repository has been uninstalled successfully!")
             print(
                 "*******************************************************************************************************"
             )
@@ -172,11 +197,11 @@ def localpip_about():
         "*******************************************************************************************************"
     )
     print(f"LocalPIP version {localpip_version}")
-    print("LocalPIP makes the Python packages installation easy...")
+    print("LocalPIP is an offline package manager for Python...")
     print("It solves packages dependencies conflict issues.")
     print("No more errors while building wheel files or compiling C++.")
     print(
-        "Internet access is required only for the first time of installation of LocalPIP."
+        "Internet access is required only for the first time of installation of LocalPIP repo."
     )
     print(
         "Once LocalPIP repository is locally installed, you can install packages completely offline."
@@ -222,7 +247,7 @@ def download_packages(action):
 
     if download.startswith("y"):
         print()
-        print("Download starting ...")
+        print("Download is starting ...")
         print()
         command = 'if (Test-Path "C:\\Program64\\Python\\temp") {Remove-Item "C:\\Program64\\Python\\temp" -Recurse -Force}'
         start_PS = powershell(command)
@@ -270,12 +295,12 @@ def download_packages(action):
                 proxy_status = 1
                 print("Download is almost complete.")
                 print()
-                print("Downloading last package, please wait...")
+                print("Downloading the last package, please wait...")
         else:
             proxy_status = 0
             print("Download is almost complete.")
             print()
-            print("Downloading last package, please wait...")
+            print("Downloading the last package, please wait...")
 
         # Remove the old packages folder
         command = 'if (Test-Path "C:\\Program64\\Python\\Packages") {Remove-Item "C:\\Program64\\Python\\Packages" -Recurse -Force}'
@@ -382,11 +407,15 @@ def download_packages(action):
 # defining the command
 def check_action(action):
     if action == "install".lower():
-        return action
+        return "install"
     elif action == "uninstall".lower():
-        return action
+        return "uninstall"
     elif action == "upgrade".lower():
-        return action
+        return "upgrade"
+    elif action == "wheel".lower():
+        return "wheel"
+    elif action == "download".lower():
+        return "download"
     else:
         info("Error: wrong option > ", action)
 
@@ -413,6 +442,23 @@ def check_packages():
             exitapp()
 
 
+def select_file():
+    filetypes = (
+        ('text files', '*.txt'),
+    )
+
+    filename = fd.askopenfilename(
+        title='Open a file',
+        initialdir='/',
+        filetypes=filetypes)
+
+    showinfo(
+        title='Selected File',
+        message=filename
+    )
+    return filename
+
+
 def main(args=None):
     try:
         if len(sys.argv) == 1:
@@ -442,19 +488,31 @@ def main(args=None):
                 localpip_about()
                 info("Enjoy", "coding!")
 
-            elif sys.argv[1].lower() == "remove" or sys.argv[1].lower() == "delete":
+            elif (
+                sys.argv[1].lower() == "remove"
+                or sys.argv[1].lower() == "delete"
+                or sys.argv[1].lower() == "uninstall"
+            ):
                 localpip_remove()
 
             elif sys.argv[1].lower() == "upgrade":
                 localpip_upgrade()
 
+            elif (
+                sys.argv[1].lower() == "--version"
+                or sys.argv[1].lower() == "--v"
+                or sys.argv[1].lower() == "version"
+            ):
+                print(f"localpip {localpip_version}")
+                exitapp()
+
             else:
                 info("Status: command is too short", "...")
 
         # install packages
         elif len(sys.argv) == 3:
             action = check_action(sys.argv[1])
-            if action != "uninstall":
+            if action == "install" or action == "upgrade":
                 path = check_packages()
                 if (
                     sys.argv[2] == "all".lower()
@@ -465,10 +523,24 @@ def main(args=None):
                     with open(requirements) as file:
                         for req in file:
                             install(req, action, path)
+                elif (
+                    sys.argv[2] == "req".lower()
+                    or sys.argv[2] == "requirement".lower()
+                    or sys.argv[2] == "requirements".lower()
+                    or sys.argv[2] == "exigence".lower()
+                ):
+                    requirements = select_file()
+                    try:
+                        with open(requirements) as file:
+                            for req in file:
+                                install(req, action, path)
+                    except:
+                        info("Error: ", "check the requirement file!")
+                        exitapp()
                 else:
                     req = sys.argv[2]
                     install(req, action, path)
-            else:
+            elif action == "uninstall":
                 req = sys.argv[2]
                 if (
                     sys.argv[2] == "all"
@@ -479,17 +551,20 @@ def main(args=None):
                     print(
                         "*******************************************************************************************************"
                     )
-                    print("Please enter the packagename you want to uninstall.")
+                    print("Please enter the package name you want to uninstall.")
                     print(
                         "*******************************************************************************************************"
                     )
                     print()
                 else:
                     install(req, action, None)
+            else:
+                req = sys.argv[2]
+                install(req, action, None)
 
         elif len(sys.argv) > 3:
             action = check_action(sys.argv[1])
-            if action != "uninstall":
+            if action != "uninstall" or action != "download" or action != "wheel":
                 path = check_packages()
             requirements = sys.argv[2:]
             for req in requirements:
